ROMAN_LITERALS = {"I": 1, "V": 5, "X": 10, "L": 50, "C": 100, "D": 500, "M": 1000}


def _convert(roman_lit):
    try:
        literals = [ROMAN_LITERALS[l] for l in roman_lit]
    except KeyError:
        return False

    result = literals[0]

    for literal in literals[1:]:
        if literal > result:
            result = literal - result
        elif literal <= result:
            result += literal

    return result


print(_convert("ASD"))



from pathlib import Path
from setuptools import setup, find_packages 

current_dir = Path(__file__).parent.resolve()

with open(current_dir / "README.md", encoding="utf-8") as f:
    long_description = f.read()
    
setup(
    name="romana",
    version="0.1",
    packages=find_packages(),
    url="https://github.com/abstractequalsmagic/romana",
    description = "Roman numbers implemented to Python AST.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
)
